==> haskell-jose0.5-0.5.0.5-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-jose0.5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.5.0.5
id: jose-0.5.0.5-GDSZlBObJXnLt1LIKBOow1
key: jose-0.5.0.5-GDSZlBObJXnLt1LIKBOow1
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016  Fraser Tweedale
maintainer: frase@frase.id.au
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    All JWS algorithms (HMAC, ECDSA, RSASSA-PKCS-v1_5 and RSASSA-PSS)
    are implemented, however, the ECDSA implementation is is
    vulnerable to timing attacks and should therefore only be used for
    JWS verification.
    .
    The '\''Crypto.JOSE.Legacy'\'' module is provided for working with the
    Mozilla Persona (formerly BrowserID) key format.  Only RSA keys
    are supported - DSA keys cannot be used and must be handled as
    opaque objects.
category: Cryptography
author: Fraser Tweedale
exposed: True
indefinite: False
exposed-modules:
    Crypto.JOSE Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWE Crypto.JOSE.JWK Crypto.JOSE.JWS
    Crypto.JOSE.Legacy Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.AESKW Crypto.JOSE.JWA.JWK
                Crypto.JOSE.JWA.JWS Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
                Crypto.JOSE.JWS.Internal Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
abi: 123db3dc8381574171ec129b192c858f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/jose-0.5.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/jose-0.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/jose-0.5.0.5
hs-libraries: HSjose-0.5.0.5-GDSZlBObJXnLt1LIKBOow1
depends:
    base-4.10.1.0 attoparsec-0.13.2.0-1AORA640dG8HmlrlyiwzkH
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL containers-0.5.10.2
    cryptonite-0.24-26n9mVTglnwAIizKbDxtWC
    lens-4.15.4-6GPYoGX8D8oF6KL1aYwOV5
    memory-0.14.10-LwCYa6TFutlHfUbiGZd8KU
    monad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7 template-haskell-2.12.0.0
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    aeson-1.2.3.0-LNkLuLvRI8W9I8ocVQs80F
    unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV
    bytestring-0.10.8.2 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    time-1.8.0.2 network-uri-2.6.1.0-LYYrYvUJy87zSaoB2hpvT
    QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l
    quickcheck-instances-0.3.16-3UD6wLZXdsRFW21IXRqVEU
    x509-1.7.2-3neUB4bV71SHQW4bIpNwCr
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             attoparsec-0.13.2.0-1AORA640dG8HmlrlyiwzkH=1e5250700950658eff033f7537304029
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fce7541e6cf9cbf2867cdcb0a2552fb8
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=24171e0673b6d1cdc40be4d3c9a33c0e
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             cryptonite-0.24-26n9mVTglnwAIizKbDxtWC=200c027bd3a4a1992644ead706f50b7b
             lens-4.15.4-6GPYoGX8D8oF6KL1aYwOV5=149453c0fd97dd6307c9aac0ba5c5778
             memory-0.14.10-LwCYa6TFutlHfUbiGZd8KU=3fa6db0e75ddbe9767a7d9705b7f2f61
             monad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq=4ec556bd12094801e7a60ce812cb4f05
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=863c6a42773abd5c980b4318cc858c44
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=c20d058560be9a4b5e941a33ed437bf5
             aeson-1.2.3.0-LNkLuLvRI8W9I8ocVQs80F=46287d49060ec1324ce6cfe2c348dbdf
             unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV=b12cdae8ac228affcce9703d4cef3dce
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             network-uri-2.6.1.0-LYYrYvUJy87zSaoB2hpvT=eb2c71a3c16909d5272749b4cd94d59c
             QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l=12616b561aced170e61d60f985fc5a23
             quickcheck-instances-0.3.16-3UD6wLZXdsRFW21IXRqVEU=f3c1ad985d3318c48c54ea337fc56378
             x509-1.7.2-3neUB4bV71SHQW4bIpNwCr=2cc8022b4efba633dccf57effe50b386
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=aa687f07efbeaeb82a30478c8f07e96e
haddock-interfaces: /usr/share/doc/haskell-jose0.5/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose0.5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jose0.5-0.5.0.5-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-jose0.5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.5.0.5
id: jose-0.5.0.5-68u9VYbMRMdJiQZEaObbga
key: jose-0.5.0.5-68u9VYbMRMdJiQZEaObbga
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016  Fraser Tweedale
maintainer: frase@frase.id.au
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    All JWS algorithms (HMAC, ECDSA, RSASSA-PKCS-v1_5 and RSASSA-PSS)
    are implemented, however, the ECDSA implementation is is
    vulnerable to timing attacks and should therefore only be used for
    JWS verification.
    .
    The '\''Crypto.JOSE.Legacy'\'' module is provided for working with the
    Mozilla Persona (formerly BrowserID) key format.  Only RSA keys
    are supported - DSA keys cannot be used and must be handled as
    opaque objects.
category: Cryptography
author: Fraser Tweedale
exposed: True
indefinite: False
exposed-modules:
    Crypto.JOSE Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWE Crypto.JOSE.JWK Crypto.JOSE.JWS
    Crypto.JOSE.Legacy Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.AESKW Crypto.JOSE.JWA.JWK
                Crypto.JOSE.JWA.JWS Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
                Crypto.JOSE.JWS.Internal Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
abi: e33f117388f3e8f20ef074f2d8b04a69
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/jose-0.5.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/jose-0.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/jose-0.5.0.5
hs-libraries: HSjose-0.5.0.5-68u9VYbMRMdJiQZEaObbga
depends:
    base-4.10.1.0 attoparsec-0.13.2.0-1AORA640dG8HmlrlyiwzkH
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL containers-0.5.10.2
    cryptonite-0.24-AbMbC6aV1yXBOkl7PKprpb
    lens-4.15.4-6GPYoGX8D8oF6KL1aYwOV5
    memory-0.14.11-3SpbaRkSFfh8uo9jYloypK
    monad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7 template-haskell-2.12.0.0
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    aeson-1.2.3.0-LNkLuLvRI8W9I8ocVQs80F
    unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV
    bytestring-0.10.8.2 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    time-1.8.0.2 network-uri-2.6.1.0-LYYrYvUJy87zSaoB2hpvT
    QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l
    quickcheck-instances-0.3.16-3UD6wLZXdsRFW21IXRqVEU
    x509-1.7.2-2F1I2nndqe6pc3P9IRXsI
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             attoparsec-0.13.2.0-1AORA640dG8HmlrlyiwzkH=1e5250700950658eff033f7537304029
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fce7541e6cf9cbf2867cdcb0a2552fb8
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=24171e0673b6d1cdc40be4d3c9a33c0e
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             cryptonite-0.24-AbMbC6aV1yXBOkl7PKprpb=7a2e0a10ed357dffdebbe0f843fb1bc0
             lens-4.15.4-6GPYoGX8D8oF6KL1aYwOV5=149453c0fd97dd6307c9aac0ba5c5778
             memory-0.14.11-3SpbaRkSFfh8uo9jYloypK=c6c4c617bf03bbd1c14846dd5fa74fd6
             monad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq=4ec556bd12094801e7a60ce812cb4f05
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=863c6a42773abd5c980b4318cc858c44
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=c20d058560be9a4b5e941a33ed437bf5
             aeson-1.2.3.0-LNkLuLvRI8W9I8ocVQs80F=46287d49060ec1324ce6cfe2c348dbdf
             unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV=b12cdae8ac228affcce9703d4cef3dce
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             network-uri-2.6.1.0-LYYrYvUJy87zSaoB2hpvT=eb2c71a3c16909d5272749b4cd94d59c
             QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l=12616b561aced170e61d60f985fc5a23
             quickcheck-instances-0.3.16-3UD6wLZXdsRFW21IXRqVEU=f3c1ad985d3318c48c54ea337fc56378
             x509-1.7.2-2F1I2nndqe6pc3P9IRXsI=e0cc787dc977659fabca83490388db1f
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=aa687f07efbeaeb82a30478c8f07e96e
haddock-interfaces: /usr/share/doc/haskell-jose0.5/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose0.5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
